# ConnectorCloudRouting

Routing configuration common to all types of connectors 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**point_of_presence_tags** | [**[FeatureTagName]**](FeatureTagName.md) | A list of feature tags describing point of presences to establish tunnels with. The connector will connector to any point of presence identified by at least one the tags.  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


